#!/bin/bash

# Restore environment variables (if there is anything to restore)
if [[ ! -z "${PATH_CONDA_OMNISCIDB_BACKUP+x}" ]]
then
  export PATH="${PATH_CONDA_OMNISCIDB_BACKUP}"
  unset PATH_CONDA_OMNISCIDB_BACKUP
fi

